@@ -9,13 +9,15 @@ class Config:
     except Exception as e:
         print('Docker not found in your machine, Pls install')
         #print(str(e))
-        exit(-1)
+        exit(3) ## docker/system error
 
     boman_url = "https://dashboard.boman.ai/v2/"  ## boman server ip // https://dashboard.boman.ai http://192.168.1.6:3000
 
     sast_present = None
     sast_lang = None
     sast_target = None
+    #sast_env = None ## for snyk
+
    
     sast_scan_status = None
     sast_upload_status = None
@@ -25,6 +27,7 @@ class Config:
     dast_present = None
     dast_target = None
     dast_type = None
+    dast_api_type = None
 
     dast_scan_status = None
     dast_upload_status = None
@@ -51,6 +54,7 @@ class Config:
     sast_build_dir = None
     sca_build_dir = None
 
+
     secret_scan_present = None
 
     build_dir = None 
@@ -74,4 +78,4 @@ class Config:
 
     log_level = "INFO"
 
-    version = 'v0.11'
\ No newline at end of file
+    version = 'v1.02'
\ No newline at end of file
