@@ -20,6 +20,7 @@ def authorize():
         #print('res:',json.loads(res.content))
     except requests.ConnectionError:
        logging.error("Can't connect to the Server while authorizing, Please check your Internet connection.")
+       exit(1) #server/saas error
     else:
         if res.status_code == 200:
             try:
@@ -37,9 +38,10 @@ def authorize():
 
                 return 1    
             except:
-                logging.error('Problem when authenticating with server, Check with boman.ai team id scan doesnt completed')    
+                logging.error('Problem when authenticating with server, Check with boman.ai team id scan doesnt completed')  
+                exit(1) ## server error  
                     
 
         elif res.status_code == 401:
             logging.error('Unauthorized Access. Check the tokens')	
-    exit(-1)
+    exit(2) ##auth error
