@@ -44,7 +44,7 @@ docker = Config.docker_client
 ### function to init the scan and will check the docker is in place
 def init():
 
-    print('#################################### -  BOMAN Scanner Initiated - ####################################')
+    print('New Scan has been Initiated')
     logging.info('Checking for Docker in the Env')
     try:
         #docker = docker.from_env()
@@ -55,7 +55,7 @@ def init():
     except Exception as e:
         logging.error('Docker not found in your machine, Pls install')
         #print(str(e))
-        exit(-1)
+        exit(3) ## docker/system error
 
 
 
@@ -73,7 +73,7 @@ def runImage(data=None,type=None):
 
 
 
-    print(data['image'])
+    #print(data['image'])
     docker_image = data['image']
     #lang= None
     tool_name =data['tool']
@@ -83,12 +83,13 @@ def runImage(data=None,type=None):
     tool_id= data['tool_id']
     scan_details_id= data['scan_details_id']
     conversion_required = data['conversion_required']
+   
 
     #print(docker_image,tool_name,command_line,output_file,will_generate_output,tool_id,scan_details_id)
 
     if docker_image is None:
         print('Problem with running the scanner, image not specified.')
-        exit('-1')
+        exit('3') ## docker/system error
 
     try:
 
@@ -102,6 +103,19 @@ def runImage(data=None,type=None):
 
     logging.info('Running all the scans/docker with the user %s',userid)
 
+
+    try:
+        logging.info('environment var configured for the scan is not picked up by the cli ')
+        #raw_env = 'SNYK_TOKEN=3884117f-5c4f-45e4-a171-ec8e71470203,test=test'
+        env = data['env']
+        env_var =  env.split(',')
+        logging.info('environment var configured for the scan is %s',str(env_var))
+    except:
+        env_var = ['test=test']
+        logging.info('environment var configuration failed or cant find the variables from sass')
+
+
+
     if type == 'SAST':
         target_file = Config.sast_target
         Utils.checkImageAlreadyExsist(docker_image)
@@ -117,10 +131,59 @@ def runImage(data=None,type=None):
         detach = True if data['detach'] == 1 else False
         container_output = None
         try:
-            Config.build_dir = Config.sast_build_dir
-            container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
-                           'bind': data['bind']}}, user=userid,detach=detach)
-            logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+
+            if tool_name == 'Codeql':
+
+
+                logging.info('processing commands for the codeql')
+
+                codeql_command = command_line.split(',')
+
+                logging.info('Building the project using codeql')
+
+                try:
+                    Config.build_dir = Config.sast_build_dir
+                    container_output = docker.containers.run(docker_image, codeql_command[0], volumes={Config.sast_build_dir: {
+                            'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
+                    logging.info('[SUCCESS]: %s buidling completed',tool_name)
+
+                except errors.ContainerError as exc:
+                    msg='\n The following error has been recorded while building project'
+                    Utils.logError(msg,str(exc))
+                    Utils.logError('details',str(container_output))
+                    Config.sast_scan_status = 'Completed'
+                    Config.sast_errors = 'Unrecongnized error recorded while builiding, [message from tool',str(exc),']'
+                    logging.error('%s',str(exc))
+                    logging.error('%s',str(container_output))
+
+
+
+                logging.info('Analyzing/scanning the project using codeql')
+
+                try:
+                    Config.build_dir = Config.sast_build_dir
+                    container_output = docker.containers.run(docker_image, codeql_command[1], volumes={Config.sast_build_dir: {
+                            'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
+                    logging.info('[SUCCESS]: %s Analyzing completed',tool_name)
+
+                except errors.ContainerError as exc:
+                    msg='\n The following error has been recorded while analyzing project'
+                    Utils.logError(msg,str(exc))
+                    Config.sast_scan_status = 'Completed'
+                    Config.sast_errors = 'Unrecongnized error recorded while analyzing, [message from tool',str(exc),']'
+                    logging.error('%s',str(exc))
+
+                
+            else:
+                Config.build_dir = Config.sast_build_dir
+                container_output = docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
+                            'bind': data['bind']}}, user=userid,detach=detach,environment=env_var)
+                logging.info('[SUCCESS]: %s Scan Completed',tool_name)
+
+            
+
+
+
 
         except errors.ContainerError as exc:
             msg='\n The following error has been recorded while scanning SAST'
@@ -197,7 +260,12 @@ def runImage(data=None,type=None):
 
         if data['dynamic_comment'] == 1:
             target_url = Config.dast_target
-            command_line = "% s" % command_line.format(target_url = target_url)
+
+            if Config.dast_type == "API":
+                api_type = Config.dast_api_type
+                command_line = "% s" % command_line.format(target_url = target_url, api_type=api_type)
+            else:
+                command_line = "% s" % command_line.format(target_url = target_url)
             #print(command_line)
         try:
             Config.build_dir = Config.sast_build_dir
@@ -346,7 +414,7 @@ def uploadReport(filename,toolname,tool_id,scan_details_id,type):
             return 1
         elif r.status_code == 401 :
             logging.error('Unauthorized Access while uploading the results. Please check the app/customer tokens')
-            exit(-1)
+            exit(2)  ## Auth error
         else:
             logging.error('Problem While uploading the results.')
             logging.error('response code is %s',r.status_code)
@@ -464,7 +532,7 @@ def main():
         if Config.sast_lang is None:
             #findLang()
             logging.error('Language Not Defined. Exiting')
-            exit(-1)
+            exit(4) ## misconfig error
 
 
 
@@ -488,7 +556,16 @@ def main():
             logging.info('Loc found in the %s : %s',Config.sast_build_dir,Config.app_loc)
 
         for data in Config.sast_response:
-            runImage(data=data,type='SAST')
+
+            #data =  json.loads(Config.sast_response)
+
+            if data['scan_status'] == 0 :   
+                logging.info('No SAST Configuration found from SaaS')    
+                logging.info('Ignoring SAST Scan')
+            else:
+                print(data)
+                logging.info('SAST data found %s',type(data)) 
+                runImage(data=data,type='SAST')
 
     else:
         logging.info('Ignoring SAST Scan')
@@ -503,12 +580,21 @@ def main():
 
 
            for data in Config.dast_response:
-                runImage(data=data,type='DAST')
+
+                if data['scan_status'] == 0 :   
+                    logging.info('No DAST Configuration found from SaaS')    
+                    logging.info('Ignoring DAST Scan')
+                else:
+                    runImage(data=data,type='DAST')
            # runImage(imagename= content['data']['dast']['tool_2']['image'], toolname= content['data']['dast']['tool_2']['tool'],type='DAST',output_file=content['data']['dast']['tool_2']['output_file'],tool_id=content['data']['dast']['tool_2']['tool_id'], scan_details_id=content['data']['dast']['scan_details_id'])
 
 
         else:
             logging.info('Ignoring DAST scan, since the target is unreachable')
+            Config.dast_scan_status = 'Failed'
+            Config.dast_upload_status ='NA'
+            Config.dast_message = 'Since the target is unreachable. Scan is failed'
+
 
     else:
         logging.info('Ignoring DAST scan')
@@ -516,8 +602,18 @@ def main():
 
     if Config.sca_present is True:
         logging.info('Preparing SCA scan')
+
+        
         for data in Config.sca_response:
-            runImage(data=data,type='SCA')
+
+            if data['status'] == 0 :   
+                logging.info('No SCA Configuration found  from SaaS')    
+                logging.info('Ignoring SCA Scan')
+            else:
+                #print(data)
+                #logging.info('SAST data found %s',type(data)) 
+                runImage(data=data,type='SCA')
+            
         #print('running sca')
         ##runImage(imagename= content['data']['sca']['image'], toolname= content['data']['sca']['tool'],type='SCA',output_file=content['data']['sca']['output_file'],tool_id=content['data']['sca']['tool_id'], scan_details_id=content['data']['sca']['scan_details_id'])
     else:
@@ -525,13 +621,14 @@ def main():
 
 
 
-    return 0
+    return 1
 
 def default():
 
     parser.add_argument('-a','--action',default='init',help="Action arugment, you need to pass the value for action (eg: test-saas, test-docker, run)")
-    parser.add_argument('-u','--url',default='https://dashboard.boman.ai/v2/',help="Logging the output, default is INFO level (eg values : DEBUG, INFO)")
+    parser.add_argument('-u','--url',default='https://dashboard.boman.ai/v2/',help="Provide the URL of the boman saas (eg: Prod, On-prem)")
     parser.add_argument('-v','--version',default='show',help="will show the version of boman-cli tool",action='store_true')
+    parser.add_argument('-fb','--failBuild',default='pass',help="this is the default value exit code in boman, pass fail if you want to fail the build when boman successfully runs the scan")
     #parser.add_argument('-check-docker',help='Check you docker is present in your system is compatable to run the boman.ai')
     args = parser.parse_args()
 
@@ -549,39 +646,48 @@ def default():
 
 
 
-
+## Action argument
     if args.action == 'init':
         print('Welcome to Boman CLI',Config.version,'pass bomancli --help to view the commands args ')
-        exit(1)
+        exit(0)
     elif args.action =='run':
-        logging.info("New Scan has been Initiated")
+        logging.info("#################################### -  BOMAN Scanner Initiated - ####################################")
         if main():
-            logging.info('All tasks done')
-            exit(1)
-        else:
             logging.info('################################ BOMAN Scanning Done ################################')
             logging.info('#####################################################################################')
+            Utils.uploadLogs()
             Utils.showSummary()
-            exit(1)
+
+            ## checking the failbuild argument
+            if args.failBuild == 'fail':
+                exit(-1)
+            else:
+                exit(0)  
+
+            
+        else:
+            logging.info('All tasks done')
+            exit(0)
+           
     elif args.action =='test-saas':
         Utils.testServer()
-        exit(1)
+        exit(0)
     elif args.action =='test-docker':
         Utils.testDockerAvailable()
-        exit(1)
+        exit(0)
     elif args.action =='test-yaml':
        Validation.yamlValidation()
-       exit(1)
+       exit(0)
     else:
         print('Welcome to Boman CLI',Config.version,',pass bomancli --help to view the commands args ')
-        exit(1)
-
+        exit(0)
 
+## version argument 
     if args.version == 'show':
         print('boman-cli '.Config.version)
 
 
-    ## starting the cli
+## starting the cli
 
 
 
